@@ -6,7 +6,6 @@ from typing import TYPE_CHECKING, TypedDict
 
 from commitizen import factory, git, out
 from commitizen.exceptions import (
-    CommitMessageLengthExceededError,
     InvalidCommandArgumentError,
     InvalidCommitMessageError,
     NoCommitsFoundError,
@@ -83,7 +82,7 @@ class Check:
         """Validate if commit messages follows the conventional pattern.
 
         Raises:
-            InvalidCommitMessageError: if the commit provided not follows the conventional pattern
+            InvalidCommitMessageError: if the commit provided does not follow the conventional pattern
             NoCommitsFoundError: if no commit is found with the given range
         """
         commits = self._get_commits()
@@ -91,18 +90,24 @@ class Check:
             raise NoCommitsFoundError(f"No commit found with range: '{self.rev_range}'")
 
         pattern = re.compile(self.cz.schema_pattern())
-        invalid_msgs_content = "\n".join(
-            f'commit "{commit.rev}": "{commit.message}"'
+        invalid_commits = [
+            (commit, check.errors)
             for commit in commits
-            if not self._validate_commit_message(commit.message, pattern, commit.rev)
-        )
-        if invalid_msgs_content:
-            # TODO: capitalize the first letter of the error message for consistency in v5
+            if not (
+                check := self.cz.validate_commit_message(
+                    commit_msg=commit.message,
+                    pattern=pattern,
+                    allow_abort=self.allow_abort,
+                    allowed_prefixes=self.allowed_prefixes,
+                    max_msg_length=self.max_msg_length,
+                    commit_hash=commit.rev,
+                )
+            ).is_valid
+        ]
+
+        if invalid_commits:
             raise InvalidCommitMessageError(
-                "commit validation: failed!\n"
-                "please enter a commit message in the commitizen format.\n"
-                f"{invalid_msgs_content}\n"
-                f"pattern: {pattern.pattern}"
+                self.cz.format_exception_message(invalid_commits)
             )
         out.success("Commit validation: successful!")
 
@@ -157,24 +162,3 @@ class Check:
             if not line.startswith("#"):
                 lines.append(line)
         return "\n".join(lines)
-
-    def _validate_commit_message(
-        self, commit_msg: str, pattern: re.Pattern[str], commit_hash: str
-    ) -> bool:
-        if not commit_msg:
-            return self.allow_abort
-
-        if any(map(commit_msg.startswith, self.allowed_prefixes)):
-            return True
-
-        if self.max_msg_length is not None:
-            msg_len = len(commit_msg.partition("\n")[0].strip())
-            if msg_len > self.max_msg_length:
-                raise CommitMessageLengthExceededError(
-                    f"commit validation: failed!\n"
-                    f"commit message length exceeds the limit.\n"
-                    f'commit "{commit_hash}": "{commit_msg}"\n'
-                    f"message length limit: {self.max_msg_length} (actual: {msg_len})"
-                )
-
-        return bool(pattern.match(commit_msg))
