@@ -2,14 +2,9 @@ from __future__ import annotations
 
 import importlib
 import pkgutil
-import sys
 import warnings
-
-if sys.version_info >= (3, 10):
-    from importlib import metadata
-else:
-    import importlib_metadata as metadata
-
+from collections.abc import Iterable
+from importlib import metadata
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
