@@ -1,11 +1,7 @@
 import sys
+from importlib import metadata
 from textwrap import dedent
 
-if sys.version_info >= (3, 10):
-    from importlib import metadata
-else:
-    import importlib_metadata as metadata
-
 import pytest
 
 from commitizen import BaseCommitizen, defaults, factory
